@@ -2,6 +2,6 @@ from html_matcher.export import ExcelExporter
 from html_matcher.utils import get_files, canonical, node, get_results, html_to_json, html_to_json_improved, \
     json_to_array, json_count_elements, filter_unwanted_tags_canonical, filter_unwanted_tags
 from html_matcher.similarity import Similarity, MixedSimilarity
-from html_matcher.lcs import LongestCommonSequence, LongestCommonSequenceOptimized, Similarity
+from html_matcher.ms import MatchingSubsequences, MatchingSubsequencesOptimized, Similarity
 from html_matcher.style import StyleSimilarity
 from html_matcher.ted import AllPathTreeEditDistance, AllPathTreeEditDistanceOptimized, CustomConfig
